@@ -7,13 +7,8 @@ use Carp;
 use Scalar::Util qw/ reftype /;
 use Data::Dumper;
 use XML::XPathScript::Template::Tag;
-use Clone qw/ clone /;
-use Scalar::Util qw/ refaddr /;
 
-use overload '&{}'  => \&_overload_func,
-             q{""}  => \&_overload_quote;
-
-our $VERSION = '1.50.1';
+our $VERSION = '1.41';
 
 sub new {
    my( $class ) = @_;
@@ -24,6 +19,7 @@ sub new {
    return $self;
 }
 
+
 sub set {       ##no critic
     croak "method set called with more than two arguments" if @_ > 3;
 
@@ -95,9 +91,7 @@ sub is_alias {
 
     my $id = $self->{$tag};
 
-    my @aliases = grep {     $_ ne $tag 
-                         and refaddr( $self->{$_} ) eq refaddr( $id ) }
-                  keys %{$self};
+    my @aliases = grep { $_ ne $tag and $self->{$_} eq $id } keys %{$self};
 
     return @aliases;
 }
@@ -135,38 +129,6 @@ sub resolve {
                                                     # (and undef if nothing)
 }
 
-sub import_template {
-    my( $self, $other_template ) = @_;
-
-    carp "incorrect call for import_template(): no argument or is not a template"
-        unless $other_template and $other_template =~ /HASH/;
-
-    for my $k ( keys %$other_template ) {
-        if ( 0 == index $k, ':' ) {         # it's a namespace
-            my $ns = $k;
-            $ns =~ s/^://;
-            my $subtemplate = $self->namespace( $ns );
-            $subtemplate->import( $other_template->{$k} );
-        }
-        else {                              # it's a regular tag
-            $self->set( $k => $other_template->{$k} );
-        }
-    }
-
-    return;
-}
-
-sub _overload_func {
-    my $self = shift;
-    return sub { $self->set( @_ ) }
-}
-
-sub _overload_quote {
-    my $self = shift;
-    return $self;
-    return sub { $self };
-}
-
 1;
 
 __END__
@@ -205,35 +167,32 @@ A stylesheet's template defines the transformations and actions that
 are performed on the tags of a document as they are processed.
 
 The template of a stylesheet can be accessed via variables 
-I<$t>, I<$template> and I<$XML::XPathScript::trans>.
+I<$t> and I<$template>.
 
 
 =head1 METHODS
 
-=head2 new
+=over
 
-    $template = XML::XPathScript::Template->new
+=item new
+
+    $template = new XML::XPathScript::Template;
 
 Creates and returns a new, empty template.
 
-=head2  set
+=item  set
 
-    $template->set( $tag, \%attributes )
-    $template->set( \@tags , \%attributes )
+    $template->( $tag, \%attributes )
+    $template->set_template( \@tags , \%attributes )
 
-Updates the $tag or @tags in the template with the 
+Update the $tag or @tags in the template with the 
 given %attributes.
 
-Thank to the magic of overloading, using the $template 
-as a code reference acts as a shortcut to I<set>.
-
 Example:
 
     $template->set( 'foo' => { pre => '<a>', post => '</a>' } );
-    # or, if you prefer,
-    $template->( 'foo' => { pre => '<a>', post => '</a>' } );
 
-=head2 copy
+=item copy
 
     $template->copy( $original_tag, $copy_tag );
     $template->copy( $original_tag, $copy_tag, \@attributes );
@@ -254,16 +213,10 @@ Example:
     $template->copy( 'important' => [ qw/ urgent redHot / ], 
                         [ qw/ pre post / ] );
 
-=head2 import_template
+=item alias
 
-    $template->import_template( $other_template )
-
-Imports another template into the current one.
-
-=head2 alias
-
-    $template->alias( $original_tag => $alias_tag )
-    $template->alias( $original_tag => \@alias_tags )
+    $template->alias( $original_tag => $alias_tag );
+    $template->alias( $original_tag => \@alias_tags );
 
 Makes the target tags aliases to the original tag. Further
 modifications that will be done on any of these tags will 
@@ -272,18 +225,16 @@ be reflected on all others.
 Example:
 
     $template->alias( 'foo' => 'bar' );
-                            
-    # also modifies 'foo'
-    $template->set( 'bar' => { pre => '<u>' } );  
+    $template->set( 'bar' => { pre => '<u>' } );  # also modify 'foo'
 
 
-=head2 is_alias
+=item is_alias
 
     @aliases = $template->is_alias( $tag )
 
 Returns all tags that are aliases to $tag. 
 
-=head2 unalias
+=item unalias
 
     $template->unalias( $tag )
 
@@ -298,7 +249,7 @@ Example:
     $template->set( 'bar' => { pre => '<c>' } );    # affects only bar
     $template->set( 'baz' => { pre => '<b>' } );    # affects foo and baz
 
-=head2 clear
+=item clear
 
     $template->clear()
     $template->clear( \@tags )
@@ -309,7 +260,7 @@ Example:
 
     $template->clear([ 'foo', 'bar' ]);
 
-=head2 dump
+=item dump
 
     $template->dump()
     $template->dump( @tags )
@@ -322,16 +273,16 @@ Example:
     <%= $template->dump( 'foo' ) %>
     
     # will yield something like
-    #
+
     # $template = {
-    #    foo => {
-    #        post => '</bar>',
-    #        pre  => '<bar>',
-    #    }
-    # };
+    #                'foo' => {
+    #                            'post' => '</bar>',
+    #                            'pre' => '<bar>'
+    #                        }
+    #             };
 
 
-=head2 namespace
+=item namespace
 
     my $subtemplate = $template->namespace( $uri );
 
@@ -343,7 +294,7 @@ Example:
     my $subtemplate = $template->namespace( 'http://www.www3c.org/blah/' );
     $subtemplate->set( 'foo' => { 'pre' => "within 'blah' namespace" } );
 
-=head2 resolve
+=item resolve
 
     $tag = $template->resolve( $namespace, $tagname );
     $tag = $template->resolve( $tagname );
@@ -389,6 +340,8 @@ Example:
     $template->resolve( 'http://blah', 'foo' )->get( 'pre' );  # returns 'c'
     $template->resolve( 'http://blah', 'baz' )->get( 'pre' );  # returns 'd'
 
+=back
+
 =head1 BACKWARD COMPATIBILITY
 
 Prior to version 1.0 of XML::XPathScript, the template of a
